lxml API Reference — lxml documentation

Skip to main content
`Ctrl`+`K`

# lxml API Reference

- lxml package
  - Subpackages
    - lxml.html package
    - lxml.isoschematron package
  - Submodules
    - lxml.ElementInclude module
    - lxml.builder module
    - lxml.cssselect module
    - lxml.doctestcompare module
    - lxml.etree module
    - lxml.objectify module
    - lxml.sax module
  - Module contents
    - `get_include()`

# Indices and tables

- Index

- Module Index

- Search Page